decode_nulls

Function decode_nulls 

pub fn decode_nulls(rows: &[&[u8]]) -> Option<NullBuffer>
Decodes a single byte from each row, interpreting 0x01 as a valid value and all other values as a null. Optionally returns None if there are no null values.