decode

Function decode 

pub(crate) unsafe fn decode<ListLikeImpl: GenericListArrayOrMap>(
    converter: &RowConverter,
    rows: &mut [&[u8]],
    field: &SortField,
    validate_utf8: bool,
) -> Result<ListLikeImpl, ArrowError>
Decodes an array from rows with the provided options

Safety

rows must contain valid data for the provided converter