fn list_like_element_encoded_len(
rows: &Rows,
range: Option<Range<usize>>,
) -> usizeExpand description
Computes the encoded length for a single list/map element given its child rows.
This is used by list types (List, LargeList, ListView, LargeListView) and by Map to determine the encoded length of a list element/map entry. For null elements, returns 1 (null sentinel only). For valid elements, returns 1 + the sum of padded lengths for each child row.