pub(crate) fn decode_nulls_sentinel(
rows: &[&[u8]],
options: SortOptions,
) -> Option<NullBuffer>Expand description
Decodes a single byte from each row, where a valid value is determined via
a configurable sentinel. Optionally returns None if there are no null values.